@@ -8,10 +8,16 @@ from logging import getLogger
 from pathlib import Path
 from typing import Iterator, List, Literal, NamedTuple, Optional, Sequence, Union
 
-from pydantic import Extra, Field, ValidationError, root_validator, validator
-from pydantic.error_wrappers import ErrorWrapper
-from pydantic.main import BaseModel, ModelMetaclass
-
+from npe2._pydantic_compat import (
+    BaseModel,
+    ErrorWrapper,
+    Extra,
+    Field,
+    ModelMetaclass,
+    ValidationError,
+    root_validator,
+    validator,
+)
 from npe2.types import PythonName
 
 from . import _validators
@@ -122,20 +128,19 @@ class PluginManifest(ImportExportModel):
     icon: str = Field(
         "",
         description="The path to a square PNG icon of at least 128x128 pixels (256x256 "
-        "for Retina screens). May be one of:\n"
-        "  - a secure (https) URL\n"
-        "  - a path relative to the manifest file, (must be shipped in the sdist)\n"
-        "  - a string in the format `{package}:{resource}`, where `package` and "
+        "for Retina screens). May be one of: "
+        "<ul><li>a secure (https) URL </li>"
+        "<li>a path relative to the manifest file, (must be shipped in the sdist)</li>"
+        "<li>a string in the format `{package}:{resource}`, where `package` and "
         "`resource` are arguments to `importlib.resources.path(package, resource)`, "
-        "(e.g. `top_module.some_folder:my_logo.png`).",
+        "(e.g. `top_module.some_folder:my_logo.png`).</li></ul>",
     )
     _validate_icon_path = validator("icon", allow_reuse=True)(_validators.icon_path)
 
     categories: List[Category] = Field(
         default_factory=list,
         description="A list of categories that this plugin belongs to. This is used to "
-        "help users discover your plugin. Allowed values:\n"
-        f"`[{', '.join(Category)}]`",
+        f"help users discover your plugin. Allowed values: `[{', '.join(Category)}]`",
     )
     # Plugins rely on certain guarantees to interoperate propertly with the
     # plugin engine. These include the manifest specification, conventions
@@ -438,9 +443,8 @@ class PluginManifest(ImportExportModel):
             If the name does not resolve to either a distribution name or a filename.
 
         """
-        from pydantic import ValidationError
-
         from npe2 import PluginManifest
+        from npe2._pydantic_compat import ValidationError
 
         try:
             return PluginManifest.from_file(package_or_filename)
